@@ -19,7 +19,9 @@
 
 #include "mod_chxj.h"
 
-extern chxjconvrule_entry* chxj_apply_convrule(request_rec *r, apr_array_header_t *convrules);
+extern chxjconvrule_entry* chxj_apply_convrule(
+  request_rec*        r, 
+  apr_array_header_t* convrules);
 
 #endif
 /*
