@@ -21,9 +21,19 @@
 #define DEFAULT_IMAGE_CACHE_DIR "/tmp"
 
 
-int chxj_img_conv_format_handler(request_rec* r);
-char* chxj_exchange_image(request_rec *r, const char** src, apr_size_t* len);
-int chxj_trans_name(request_rec *r);
+extern int 
+chxj_img_conv_format_handler(
+  request_rec* r);
+
+extern char* 
+chxj_exchange_image(
+  request_rec* r, 
+  const char** src, 
+  apr_size_t*  len);
+
+extern int 
+chxj_trans_name(
+  request_rec *r);
 
 
 #endif
