@@ -21,6 +21,9 @@
 #define ESCAPE_CHAR_GT "&gt;"
 
 
-char* chxj_load_emoji_data( Doc* doc, apr_pool_t *p, mod_chxj_config* conf);
+extern char* chxj_load_emoji_data(
+  Doc*             doc, 
+  apr_pool_t*      p, 
+  mod_chxj_config* conf);
 
 #endif
