@@ -34,39 +34,42 @@ typedef enum {
 #define CHXJ_PIC_NG                (0x00)
 
 #include "mod_chxj.h"
+#include "chxj_cookie.h"
 
 
-typedef struct _device_table_t {
-  struct _device_table_t* next;
-  const char* device_id;
-  const char* device_name;
-  spec_type html_spec_type;
-  int width;
-  int heigh;
+typedef struct device_table_t device_table;
+
+struct device_table_t {
+  struct device_table_t* next;
+  const char*            device_id;
+  const char*            device_name;
+  spec_type              html_spec_type;
+  int                    width;
+  int                    heigh;
   /*--------------------------------------------------------------------------*/
   /* Walll Paper Size                                                         */
   /*--------------------------------------------------------------------------*/
-  int wp_width;
-  int wp_heigh;
+  int                    wp_width;
+  int                    wp_heigh;
   /*--------------------------------------------------------------------------*/
   /* Cache Size                                                               */
   /*--------------------------------------------------------------------------*/
-  int cache;
+  int                    cache;
   /*--------------------------------------------------------------------------*/
   /* Correspondence image format                                              */
   /* 1: It is possible to display it.                                         */
   /* 0: It is not possible to display it.                                     */
   /*--------------------------------------------------------------------------*/
-  int available_gif;
-  int available_jpeg;
-  int available_png;
-  int available_bmp2;
-  int available_bmp4;
+  int                    available_gif;
+  int                    available_jpeg;
+  int                    available_png;
+  int                    available_bmp2;
+  int                    available_bmp4;
   /*--------------------------------------------------------------------------*/
   /* Resolution                                                               */
   /*--------------------------------------------------------------------------*/
-  int dpi_width;
-  int dpi_heigh;
+  int                    dpi_width;
+  int                    dpi_heigh;
   /*--------------------------------------------------------------------------*/
   /* Color number type                                                        */
   /* 2       : 2        Colors                                                */
@@ -77,34 +80,42 @@ typedef struct _device_table_t {
   /* 262144  : 262144   Colors                                                */
   /* 15680000: 15680000 over colors                                           */
   /*--------------------------------------------------------------------------*/
-  int color;
-  char* emoji_type;
+  int                    color;
+  char*                  emoji_type;
+};
 
+typedef struct device_table_list_t  device_table_list;
 
-} device_table;
+struct device_table_list_t {
+  struct device_table_list_t* next;
 
-typedef struct _device_table_list_t {
-  struct _device_table_list_t* next;
-  char* pattern;
-  ap_regex_t* regexp;
+  char*         pattern;
+  ap_regex_t*   regexp;
   device_table* table;
   device_table* tail;
-} device_table_list;
+};
 
-typedef struct _exchange_t {
+typedef struct converter_t converter_t;
+
+struct converter_t {
   /* convert routine */
-  char* (*exchange)(request_rec* r,
-                    struct _device_table_t* spec,
-                    const char* src, 
-                    apr_size_t srclen, 
-                    apr_size_t *dstlen,
-                    struct _chxjconvrule_entry* entryp);
+  char* (*converter)(request_rec*                r,
+                     struct device_table_t*      spec,
+                     const char*                 src, 
+                     apr_size_t                  srclen, 
+                     apr_size_t*                 dstlen,
+                     struct chxjconvrule_entry* entryp,
+                     cookie_t*                   cookie);
 
-  char* (*encoder)(request_rec *r, const char* src, apr_size_t* len);
-} exchange_t;
+  char* (*encoder)(request_rec* r,
+                   const char*  src,
+                   apr_size_t*  len);
+};
 
-extern exchange_t exchange_routine[];
+extern converter_t convert_routine[];
 
-device_table* chxj_specified_device(request_rec* r, const char* user_agent);
+extern device_table* chxj_specified_device(
+  request_rec* r, 
+  const char*  user_agent);
 
 #endif
