@@ -20,6 +20,7 @@
 #include "chxj_dump.h"
 #include "chxj_img_conv.h"
 #include "chxj_qr_code.h"
+#include "chxj_encoding.h"
 
 #define GET_CHTML30(X) ((chtml30_t*)(X))
 
@@ -292,8 +293,34 @@ tag_handler chtml30_handler[] = {
     NULL,
     NULL,
   },
+  /* tagB */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagFIELDSET */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagDT */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLEGEND */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLABEL */
+  {
+    NULL,
+    NULL,
+  },
 };
 
+
 /**
  * converts from CHTML5.0 to CHTML3.0.
  *
@@ -305,17 +332,18 @@ tag_handler chtml30_handler[] = {
  */
 char*
 chxj_exchange_chtml30(
-  request_rec* r,
-  device_table* spec,
-  const char* src,
-  apr_size_t srclen,
-  apr_size_t *dstlen,
-  chxjconvrule_entry* entryp
+  request_rec*        r,
+  device_table*       spec,
+  const char*         src,
+  apr_size_t          srclen,
+  apr_size_t*         dstlen,
+  chxjconvrule_entry* entryp,
+  cookie_t*           cookie
 )
 {
   char*     dst = NULL;
   char*     ss;
-  chtml30_t   chtml30;
+  chtml30_t chtml30;
   Doc       doc;
 
 
@@ -336,6 +364,7 @@ chxj_exchange_chtml30(
   s_init_chtml30(&chtml30, &doc, r, spec);
 
   chtml30.entryp = entryp;
+  chtml30.cookie = cookie;
 
   ap_set_content_type(r, "text/html; charset=Windows-31J");
 
@@ -370,6 +399,7 @@ chxj_exchange_chtml30(
     dst = apr_psprintf(r->pool, "\n");
 
   *dstlen = strlen(dst);
+
 #ifdef DUMP_LOG
   chxj_dump_out("[src] CHTML -> CHTML3.0", dst, *dstlen);
 #endif
@@ -391,10 +421,10 @@ chxj_exchange_chtml30(
 static void
 s_init_chtml30(chtml30_t* chtml30, Doc* doc, request_rec* r, device_table* spec)
 {
-  memset(doc,   0, sizeof(Doc));
+  memset(doc,     0, sizeof(Doc));
   memset(chtml30, 0, sizeof(chtml30_t));
 
-  doc->r      = r;
+  doc->r        = r;
   chtml30->doc  = doc;
   chtml30->spec = spec;
   chtml30->out  = qs_alloc_zero_byte_string(r);
@@ -427,7 +457,7 @@ s_chtml30_search_emoji(chtml30_t* chtml30, char* txt, char** rslt)
   len = strlen(txt);
   r   = chtml30->doc->r;
 
-  if (spec == NULL)
+  if (!spec)
     DBG(r,"spec is NULL");
 
   for (ee = chtml30->conf->emoji;
@@ -454,9 +484,11 @@ s_chtml30_search_emoji(chtml30_t* chtml30, char* txt, char** rslt)
       return 0;
     }
   }
+
   return 0;
 }
 
+
 /**
  * It is a handler who processes the HTML tag.
  *
@@ -473,8 +505,8 @@ s_chtml30_start_html_tag(void* pdoc, Node* node)
   request_rec*  r;
 
   chtml30 = GET_CHTML30(pdoc);
-  doc   = chtml30->doc;
-  r     = doc->r;
+  doc     = chtml30->doc;
+  r       = doc->r;
 
   /*--------------------------------------------------------------------------*/
   /* start HTML tag                                                           */
@@ -501,8 +533,8 @@ s_chtml30_end_html_tag(void* pdoc, Node* child)
   request_rec*  r;
 
   chtml30 = GET_CHTML30(pdoc);
-  doc   = chtml30->doc;
-  r     = doc->r;
+  doc     = chtml30->doc;
+  r       = doc->r;
 
   chtml30->out = apr_pstrcat(r->pool, chtml30->out, "</html>\n", NULL);
 
@@ -525,12 +557,16 @@ s_chtml30_start_meta_tag(void* pdoc, Node* node)
   Doc*          doc;
   request_rec*  r;
   Attr*         attr;
-  int           content_type_flag = 0;
+  int           content_type_flag;
+  int           refresh_flag;
 
   chtml30 = GET_CHTML30(pdoc);
   doc     = chtml30->doc;
   r       = doc->r;
 
+  content_type_flag = 0;
+  refresh_flag      = 0;
+
   chtml30->out = apr_pstrcat(r->pool, chtml30->out, "<meta", NULL);
 
   /*--------------------------------------------------------------------------*/
@@ -539,45 +575,92 @@ s_chtml30_start_meta_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr;
        attr = qs_get_next_attr(doc,attr)) {
-    char* name   = qs_get_attr_name(doc,attr);
-    char* value  = qs_get_attr_value(doc,attr);
 
-    if (strcasecmp(name, "http-equiv") == 0) {
-      /*----------------------------------------------------------------------*/
-      /* CHTML 2.0                                                            */
-      /*----------------------------------------------------------------------*/
-      chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " http-equiv=\"", 
-                      value,
-                      "\"",
-                      NULL);
-      if ((*value == 'c' || *value == 'C') && strcasecmp(value, "content-type") == 0) {
-        content_type_flag = 1;
+    char* name;
+    char* value;
+
+    name   = qs_get_attr_name(doc,attr);
+    value  = qs_get_attr_value(doc,attr);
+
+    switch(*name) {
+    case 'h':
+    case 'H':
+      if (strcasecmp(name, "http-equiv") == 0) {
+        /*----------------------------------------------------------------------*/
+        /* CHTML 2.0                                                            */
+        /*----------------------------------------------------------------------*/
+        chtml30->out = apr_pstrcat(r->pool, 
+                                   chtml30->out, 
+                                   " http-equiv=\"", 
+                                   value,
+                                   "\"",
+                                   NULL);
+  
+        if ((*value == 'c' || *value == 'C') 
+        && strcasecmp(value, "content-type") == 0)
+          content_type_flag = 1;
+  
+        if ((*value == 'r' || *value == 'R')
+        && strcasecmp(value, "refresh") == 0)
+          refresh_flag = 1;
       }
-    }
-    else
-    if (strcasecmp(name, "content") == 0) {
-      if (content_type_flag) {
-        chtml30->out = apr_pstrcat(r->pool,
-                        chtml30->out,
-                        " ",
-                        name,
-                        "=\"",
-                        "text/html; charset=Windows-31J",
-                        "\"",
-                        NULL);
-      }
-      else {
-        chtml30->out = apr_pstrcat(r->pool,
-                        chtml30->out,
-                        " ",
-                        name,
-                        "=\"",
-                        value,
-                        "\"",
-                        NULL);
+      break;
+
+    case 'c':
+    case 'C':
+      if (strcasecmp(name, "content") == 0) {
+        if (content_type_flag) {
+          chtml30->out = apr_pstrcat(r->pool,
+                                     chtml30->out,
+                                     " ",
+                                     name,
+                                     "=\"",
+                                    "text/html; charset=Windows-31J",
+                                    "\"",
+                                    NULL);
+        }
+        else
+        if (refresh_flag) {
+          char* buf;
+          char* sec;
+          char* url;
+  
+          buf = apr_pstrdup(r->pool, value);
+  
+          url = strchr(buf, ';');
+          if (url) {
+            sec = apr_pstrdup(r->pool, buf);
+            sec[url-buf] = 0;
+            url++;
+            url = chxj_encoding_parameter(r, url);
+            url = chxj_add_cookie_parameter(r, url, chtml30->cookie);
+            chtml30->out = apr_pstrcat(r->pool,
+                                       chtml30->out,
+                                       " ",
+                                       name,
+                                       "=\"",
+                                       sec,
+                                       ";",
+                                       url,
+                                       "\"",
+                                       NULL);
+          }
+        }
+        else {
+          chtml30->out = apr_pstrcat(r->pool,
+                                     chtml30->out,
+                                     " ",
+                                     name,
+                                     "=\"",
+                                     value,
+                                     "\"",
+                                     NULL);
+        }
       }
+      break;
+
+    default:
+      break;
     }
   }
 
@@ -734,15 +817,20 @@ s_chtml30_start_base_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr;
        attr = qs_get_next_attr(doc,attr)) {
-    char* name = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
-    if (strcasecmp(name, "href") == 0) {
+
+    char* name;
+    char* value;
+
+    name = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
+
+    if ((*name == 'h' || *name == 'H') && strcasecmp(name, "href") == 0) {
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " href=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " href=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
   }
 
@@ -799,19 +887,22 @@ s_chtml30_start_body_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr;
        attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value  = qs_get_attr_value(doc,attr);
+    char* name;
+    char* value;
 
-    if (strcasecmp(name, "bgcolor") == 0) {
+    name   = qs_get_attr_name(doc,attr);
+    value  = qs_get_attr_value(doc,attr);
+
+    if ((*name == 'b' || *name == 'B') && strcasecmp(name, "bgcolor") == 0) {
       /*----------------------------------------------------------------------*/
       /* CHTML 2.0                                                            */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " bgcolor=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " bgcolor=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "text") == 0) {
@@ -819,11 +910,11 @@ s_chtml30_start_body_tag(void* pdoc, Node* node)
       /* CHTML 2.0                                                            */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " text=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " text=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "link") == 0) {
@@ -831,11 +922,11 @@ s_chtml30_start_body_tag(void* pdoc, Node* node)
       /* CHTML 2.0                                                            */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " link=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " link=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "alink") == 0) {
@@ -912,31 +1003,37 @@ s_chtml30_start_a_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr; 
        attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
 
     if (strcasecmp(name, "name") == 0) {
       /*----------------------------------------------------------------------*/
       /* CHTML1.0                                                             */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " name=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " name=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "href") == 0) {
       /*----------------------------------------------------------------------*/
       /* CHTML1.0                                                             */
       /*----------------------------------------------------------------------*/
+      value = chxj_encoding_parameter(r, value);
+      value = chxj_add_cookie_parameter(r, value, chtml30->cookie);
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " href=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " href=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "accesskey") == 0) {
@@ -956,11 +1053,11 @@ s_chtml30_start_a_tag(void* pdoc, Node* node)
       /* CHTML 2.0                                                            */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " cti=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " cti=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "ijam") == 0) {
@@ -976,9 +1073,9 @@ s_chtml30_start_a_tag(void* pdoc, Node* node)
       /* It is special only for CHTML.                                        */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " utn ", 
-                      NULL);
+                                 chtml30->out, 
+                                 " utn ", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "telbook") == 0) {
@@ -1030,6 +1127,7 @@ s_chtml30_start_a_tag(void* pdoc, Node* node)
       /* ignore */
     }
   }
+
   chtml30->out = apr_pstrcat(r->pool, chtml30->out, ">", NULL);
 
   return chtml30->out;
@@ -1177,16 +1275,20 @@ s_chtml30_start_font_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr; 
        attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
 
     if (strcasecmp(name, "color") == 0) {
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " color=\"", 
-                      value, 
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " color=\"", 
+                                 value, 
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "size") == 0) {
@@ -1256,18 +1358,25 @@ s_chtml30_start_form_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr;
        attr = qs_get_next_attr(doc,attr)) {
-    char* name = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
+
     if (strcasecmp(name, "action") == 0) {
       /*----------------------------------------------------------------------*/
       /* CHTML 1.0                                                            */
       /*----------------------------------------------------------------------*/
+      value = chxj_encoding_parameter(r, value);
+      value = chxj_add_cookie_parameter(r, value, chtml30->cookie);
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " action=\"",
-                      value,
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " action=\"",
+                                 value,
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "method") == 0) {
@@ -1275,11 +1384,11 @@ s_chtml30_start_form_tag(void* pdoc, Node* node)
       /* CHTML 1.0                                                            */
       /*----------------------------------------------------------------------*/
       chtml30->out = apr_pstrcat(r->pool, 
-                      chtml30->out, 
-                      " method=\"",
-                      value,
-                      "\"", 
-                      NULL);
+                                 chtml30->out, 
+                                 " method=\"",
+                                 value,
+                                 "\"", 
+                                 NULL);
     }
     else
     if (strcasecmp(name, "utn") == 0) {
@@ -1651,12 +1760,34 @@ s_chtml30_start_img_tag(void* pdoc, Node* node)
       /* CHTML 1.0                                                            */
       /*----------------------------------------------------------------------*/
 #ifdef IMG_NOT_CONVERT_FILENAME
+      value = chxj_encoding_parameter(r, value);
+      value = chxj_add_cookie_parameter(r, value, chtml30->cookie);
+      if (value) {
+        value = apr_psprintf(r->pool,
+                             "%s%c%s=true",
+                             value,
+                             (strchr(value, '?')) ? '&' : '?',
+                             CHXJ_COOKIE_NOUPDATE_PARAM);
+      }
+
       chtml30->out = apr_pstrcat(r->pool, 
                       chtml30->out, " src=\"",value,"\"", NULL);
 #else
+      value = chxj_img_conv(r,spec,value);
+      value = chxj_encoding_parameter(r, value);
+      value = chxj_add_cookie_parameter(r, value, chtml30->cookie);
+      if (value) {
+        value = apr_psprintf(r->pool,
+                             "%s%c%s=true",
+                             value,
+                             (strchr(value, '?')) ? '&' : '?',
+                             CHXJ_COOKIE_NOUPDATE_PARAM);
+      }
+
       chtml30->out = apr_pstrcat(r->pool, 
                       chtml30->out, " src=\"", 
-                      chxj_img_conv(r,spec,value), NULL);
+                      value, NULL);
+
       chtml30->out = apr_pstrcat(r->pool, chtml30->out, "\"", NULL);
 #endif
     }
