@@ -21,6 +21,7 @@
 #include "chxj_img_conv.h"
 #include "chxj_dump.h"
 #include "chxj_qr_code.h"
+#include "chxj_encoding.h"
 
 #define CHECK_BOX_PREFIX     "_chxj_c_"
 #define RADIO_BUTTON_PREFIX  "_chxj_r_"
@@ -89,7 +90,7 @@ static void  s_output_to_init_vars        (hdml_t* hdml, char* s);
 static int   s_hdml_search_emoji          (hdml_t* hdml, char* txt, char** rslt);
 
 static char* s_hdml_chxjif_tag            (void* pdoc, Node* node);
-static char* s_hdml_text_tag              (void* pdoc, Node* node) ;
+static char* s_hdml_text_tag              (void* pdoc, Node* node);
 
 
 tag_handler hdml_handler[] = {
@@ -293,6 +294,31 @@ tag_handler hdml_handler[] = {
     NULL,
     NULL,
   },
+  /* tagB */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagFIELDSET */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagDT */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLEGEND */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLABEL */
+  {
+    NULL,
+    NULL,
+  },
 };
 
 /**
@@ -305,18 +331,23 @@ tag_handler hdml_handler[] = {
  * @return         The character string after the converting is returned.
  */
 char*
-chxj_exchange_hdml(request_rec* r, 
-                   device_table* spec, 
-                   const char* src, 
-                   apr_size_t srclen, 
-                   apr_size_t* dstlen,
-                   chxjconvrule_entry* entryp
+chxj_exchange_hdml(
+  request_rec* r, 
+  device_table* spec, 
+  const char* src, 
+  apr_size_t srclen, 
+  apr_size_t* dstlen,
+  chxjconvrule_entry* entryp,
+  cookie_t* cookie
 )
 {
-  char*     dst = NULL;
-  char*     buf = NULL;
+  char*     dst;
+  char*     buf;
   Doc       doc;
-  hdml_t      hdml;
+  hdml_t    hdml;
+
+  dst = NULL;
+  buf = NULL;
 
   /*--------------------------------------------------------------------------*/
   /* If qrcode xml                                                            */
@@ -420,6 +451,7 @@ chxj_exchange_hdml(request_rec* r,
   return dst;
 }
 
+
 /**
  * The HDML structure is initialized. 
  * 
@@ -471,13 +503,14 @@ s_init_hdml(hdml_t* hdml, Doc* doc, request_rec* r, device_table* spec)
   hdml->out = qs_alloc_zero_byte_string(r);
 }
 
+
 static int
 s_hdml_search_emoji(hdml_t* hdml, char* txt, char** rslt)
 {
-  emoji_t* ee;
-  request_rec* r;
+  emoji_t*      ee;
+  request_rec*  r;
   device_table* spec;
-  int len;
+  int           len;
 
   spec = hdml->spec;
 
@@ -490,10 +523,11 @@ s_hdml_search_emoji(hdml_t* hdml, char* txt, char** rslt)
   for (ee = hdml->conf->emoji;
        ee;
        ee = ee->next) {
+
     unsigned char hex1byte;
     unsigned char hex2byte;
 
-    if (!ee->imode) {
+    if (! ee->imode) {
       DBG(r, "emoji->imode is NULL");
       continue;
     }
@@ -864,7 +898,10 @@ s_hdml_start_body_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node); 
     attr; 
     attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
+
+    char* name;
+
+    name  = qs_get_attr_name(doc,attr);
 
     if ((*name == 'b' || *name == 'B') && strcasecmp(name, "bgcolor")     == 0) {
       /* ignore */
@@ -945,20 +982,28 @@ s_hdml_start_a_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node);
        attr;
        attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
+
     if ((*name == 'n' || *name == 'N') && strcasecmp(name, "name") == 0) {
       /* IGNORE */
     }
     else 
     if ((*name == 'h' || *name == 'H') && strcasecmp(name, "href") == 0) {
-      if ((*value == 'm' || *value == 'M') && strncasecmp(value, "mailto:", 7) == 0) {
+      if ((*value == 'm' || *value == 'M') 
+      && strncasecmp(value, "mailto:", 7) == 0) {
+        value = chxj_encoding_parameter(hdml->doc->r, value);
         s_output_to_hdml_out(hdml, " TASK=GO DEST=\""     );
         s_output_to_hdml_out(hdml, value                  );
         s_output_to_hdml_out(hdml, "\" "                  );
       }
       else 
-      if ((*value == 't' || *value == 'T') && strncasecmp(value, "tel:", 4) == 0) {
+      if ((*value == 't' || *value == 'T') 
+      && strncasecmp(value, "tel:", 4) == 0) {
 
         s_output_to_hdml_out(hdml,  " TASK=CALL NUMBER=\"");
         s_output_to_hdml_out(hdml, &value[4]              );
@@ -1201,42 +1246,52 @@ s_hdml_start_form_tag(void* pdoc, Node* node)
   request_rec* r;
   Attr*        attr;
   Doc*         doc;
-  char*        act = NULL;
+  char*        act;
 
   hdml = GET_HDML(pdoc);
   doc  = hdml->doc;
   r    = hdml->doc->r;
+  act  = NULL;
 
   hdml->form_tmp = apr_psprintf(r->pool,
                   "<NODISPLAY NAME=F%d>\n",
                   hdml->pure_form_cnt);
   hdml->form_tmp = apr_pstrcat(r->pool,
-                           hdml->form_tmp,
-                           "<ACTION TYPE=ACCEPT TASK=GO METHOD=POST DEST=\"",NULL);
+                              hdml->form_tmp,
+                             "<ACTION TYPE=ACCEPT TASK=GO METHOD=POST DEST=\"",
+                              NULL);
   /* Get Attributes */
   for (attr = qs_get_attr(doc,node); 
        attr; 
        attr = qs_get_next_attr(doc,attr)) {
-    char* name = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
 
     if ((*name == 'a' || *name == 'A') && strcasecmp(name, "action") == 0) {
+      value = chxj_encoding_parameter(hdml->doc->r, value);
       act = apr_psprintf(r->pool, "%s", value);
       break;
     }
   }
+
   if (act) {
     hdml->form_tmp = apr_pstrcat(r->pool,
-                             hdml->form_tmp,
-                             act,
-                             NULL);
+                                 hdml->form_tmp,
+                                 act,
+                                 NULL);
   }
   hdml->form_tmp = apr_pstrcat(r->pool,
-                           hdml->form_tmp,
-                           "\" ",NULL);
+                               hdml->form_tmp,
+                               "\" ",
+                               NULL);
   hdml->form_tmp = apr_pstrcat(r->pool,
-                           hdml->form_tmp,
-                           "POSTDATA=\"", NULL);
+                               hdml->form_tmp,
+                               "POSTDATA=\"", 
+                               NULL);
 
   hdml->hdml_br_flag = 0;
 
@@ -1264,9 +1319,9 @@ s_hdml_end_form_tag(void* pdoc, Node* child)
   s_output_to_postdata(hdml, "_chxj_dmy=");
 
   hdml->form_tmp = apr_pstrcat(r->pool, 
-                             hdml->form_tmp,
-                             hdml->postdata[hdml->pure_form_cnt],
-                             NULL);
+                               hdml->form_tmp,
+                               hdml->postdata[hdml->pure_form_cnt],
+                               NULL);
 
   hdml->form_tmp = apr_pstrcat(r->pool,
                                hdml->form_tmp,
@@ -1285,6 +1340,7 @@ s_hdml_end_form_tag(void* pdoc, Node* child)
   return hdml->out;
 }
 
+
 /**
  * It is a handler that takes charge of the processing of the input tag. 
  *
@@ -1300,7 +1356,7 @@ s_hdml_start_input_tag(void* pdoc, Node* node)
   Attr*      attr;
 
   hdml = GET_HDML(pdoc);
-  doc = hdml->doc;
+  doc  = hdml->doc;
 
   /*--------------------------------------------------------------------------*/
   /* The attribute of the input tag is acquired.                              */
@@ -1308,8 +1364,12 @@ s_hdml_start_input_tag(void* pdoc, Node* node)
   for (attr = qs_get_attr(doc,node); 
        attr; 
        attr = qs_get_next_attr(doc,attr)) {
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
 
     if ((*name == 't'|| *name == 'T') && strcasecmp(name, "type") == 0) {
       if ((*value == 't' || *value == 'T') && strcasecmp(value, "text") == 0) {
@@ -1400,31 +1460,36 @@ s_hdml_start_input_tag(void* pdoc, Node* node)
 static void
 s_hdml_do_input_text_tag(hdml_t* hdml, Node* tag)
 {
-  Doc*          doc   = hdml->doc;
-  request_rec*  r     = doc->r;
+  Doc*          doc;
+  request_rec*  r;
   char*         mlen;
   char*         val;
   char*         is;
   char*         nm;
   char*         fmt;
   int           ii;
+
+  doc   = hdml->doc;
+  r     = doc->r;
+
   s_hdml_tag_output_upper_half(hdml, tag);
 
   hdml->card_cnt++;
   s_output_to_hdml_out(hdml, 
-                  apr_psprintf(r->pool,
-                          "<A TASK=GOSUB LABEL=\x93\xfc\x97\xcd DEST=#D%d "
-                          "VARS=\"V=$%s%02d\" RECEIVE=%s%02d>",
-                          hdml->card_cnt,
-                          s_get_form_no(r, hdml),
-                          hdml->var_cnt[hdml->pure_form_cnt],
-                          s_get_form_no(r, hdml),
-                          hdml->var_cnt[hdml->pure_form_cnt]
-                  ));
+                       apr_psprintf(r->pool,
+                                    "<A TASK=GOSUB LABEL=\x93\xfc\x97\xcd DEST=#D%d "
+                                    "VARS=\"V=$%s%02d\" RECEIVE=%s%02d>",
+                                    hdml->card_cnt,
+                                    s_get_form_no(r, hdml),
+                                    hdml->var_cnt[hdml->pure_form_cnt],
+                                    s_get_form_no(r, hdml),
+                                    hdml->var_cnt[hdml->pure_form_cnt]
+                      ));
 
   s_output_to_hdml_out(hdml, 
-                  apr_psprintf(r->pool, "[$%s%02d]</A>\n"  , 
-                          s_get_form_no(r, hdml),
+                       apr_psprintf(r->pool, 
+                                    "[$%s%02d]</A>\n"  , 
+                                    s_get_form_no(r, hdml),
                           hdml->var_cnt[hdml->pure_form_cnt]));
 
   /*--------------------------------------------------------------------------*/
@@ -1444,11 +1509,11 @@ s_hdml_do_input_text_tag(hdml_t* hdml, Node* tag)
   }
 
   s_output_to_postdata(hdml, 
-                  apr_psprintf(r->pool, 
-                          "%s=$%s%02d", 
-                          nm,
-                          s_get_form_no(r, hdml),
-                          hdml->var_cnt[hdml->pure_form_cnt]));
+                       apr_psprintf(r->pool, 
+                                    "%s=$%s%02d", 
+                                    nm,
+                                    s_get_form_no(r, hdml),
+                                    hdml->var_cnt[hdml->pure_form_cnt]));
 
   mlen = qs_get_maxlength_attr  (doc, tag, r);
   is   = qs_get_istyle_attr     (doc, tag, r);
@@ -1472,25 +1537,28 @@ s_hdml_do_input_text_tag(hdml_t* hdml, Node* tag)
   }
 
   s_output_to_hdml_card(hdml, 
-                  " MARKABLE=FALSE>\n"
-                  "<ACTION TYPE=ACCEPT TASK=RETURN RETVALS=$V>\n"
-                  "</ENTRY>\n");
+                        " MARKABLE=FALSE>\n"
+                        "<ACTION TYPE=ACCEPT TASK=RETURN RETVALS=$V>\n"
+                        "</ENTRY>\n");
 
   if (val) 
     s_output_to_init_vars(hdml, 
-                    apr_psprintf(r->pool, "%s%02d=%s", 
-                        s_get_form_no(r, hdml),
-                        hdml->var_cnt[hdml->pure_form_cnt],
-                        ap_escape_uri(r->pool,val)));
+                          apr_psprintf(r->pool, 
+                                       "%s%02d=%s", 
+                                       s_get_form_no(r, hdml),
+                                       hdml->var_cnt[hdml->pure_form_cnt],
+                                       ap_escape_uri(r->pool,val)));
   else 
     s_output_to_init_vars(hdml, 
-                    apr_psprintf(r->pool, "%s%02d=", 
-                        s_get_form_no(r, hdml),
-                        hdml->var_cnt[hdml->pure_form_cnt]));
+                          apr_psprintf(r->pool, 
+                                       "%s%02d=", 
+                                       s_get_form_no(r, hdml),
+                                       hdml->var_cnt[hdml->pure_form_cnt]));
 
   hdml->var_cnt[hdml->pure_form_cnt]++;
 }
 
+
 /**
  * The substitution processing of tag "input type = password" is done. 
  * 
@@ -1501,27 +1569,31 @@ s_hdml_do_input_text_tag(hdml_t* hdml, Node* tag)
 static void
 s_hdml_do_input_password_tag(hdml_t* hdml, Node* tag)
 {
-  Doc*            doc = hdml->doc;
-  request_rec*    r   = doc->r;
+  Doc*            doc;
+  request_rec*    r;
   char*           mlen;
   char*           val;
   char*           is;
   char*           nm;
   char*           fmt;
 
+  doc = hdml->doc;
+  r   = doc->r;
+
   s_hdml_tag_output_upper_half(hdml, tag);
 
   hdml->card_cnt++;
   s_output_to_hdml_out(hdml, "<A TASK=GOSUB LABEL=\"\x93\xfc\x97\xcd\" DEST=");
   s_output_to_hdml_out(hdml, apr_psprintf(r->pool, "#D%d ", hdml->card_cnt));
   s_output_to_hdml_out(hdml, 
-                  apr_psprintf(r->pool, "VARS=\"V=$%s%02d\" ", 
-                          s_get_form_no(r, hdml),
-                          hdml->var_cnt[hdml->pure_form_cnt]));
+                       apr_psprintf(r->pool, 
+                                    "VARS=\"V=$%s%02d\" ", 
+                                    s_get_form_no(r, hdml),
+                                    hdml->var_cnt[hdml->pure_form_cnt]));
 
   s_output_to_hdml_out(hdml, 
                   apr_psprintf(r->pool, "RECEIVE=%s%02d>"  , 
-                          s_get_form_no(r, hdml),
+                               s_get_form_no(r, hdml),
                           hdml->var_cnt[hdml->pure_form_cnt]));
   s_output_to_hdml_out(hdml, 
                   apr_psprintf(r->pool, "[$%s%02d]</A>\n"  , 
@@ -2180,6 +2252,7 @@ s_hdml_start_img_tag(void* pdoc, Node* node)
     char* value = qs_get_attr_value(doc,attr);
 
     if ((*name == 's' || *name == 'S') && strcasecmp(name, "src") == 0) {
+      value = chxj_encoding_parameter(hdml->doc->r, value);
       s_output_to_hdml_out(hdml, " src=\"");
 #ifdef IMG_NOT_CONVERT_FILENAME
       s_output_to_hdml_out(hdml, value    );
@@ -2568,9 +2641,11 @@ qs_out_apr_pstrcat(request_rec* r, char* o, char* s, int* len)
 static char*
 s_get_form_no(request_rec* r, hdml_t* hdml) 
 {
-  char *result;
+  char*          result;
   apr_time_exp_t tm;
-  unsigned long fc = hdml->form_cnt;
+  unsigned long  fc;
+
+  fc = hdml->form_cnt;
 
   apr_time_exp_tz(&tm, hdml->form_cnt, 0);
 
@@ -2594,8 +2669,11 @@ static void
 s_hdml_count_radio_tag(hdml_t* hdml, Node* node) 
 {
   Node*         child;
-  Doc*          doc       = hdml->doc; 
-  request_rec*  r         = doc->r;
+  Doc*          doc; 
+  request_rec*  r;
+
+  doc       = hdml->doc; 
+  r         = doc->r;
 
   /*--------------------------------------------------------------------------*/
   /* All the child nodes of the specified node are scanned.                   */
@@ -2753,7 +2831,9 @@ s_output_to_hdml_card(hdml_t* hdml, char* s)
 static void
 s_output_to_postdata(hdml_t* hdml, char* s)
 {
-  request_rec*          r = hdml->doc->r;
+  request_rec*          r;
+
+  r = hdml->doc->r;
 
   if (strlen(hdml->postdata[hdml->pure_form_cnt]))
     hdml->postdata[hdml->pure_form_cnt] =
