@@ -14,16 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#if 0
-#include <wand/magick_wand.h>
-
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-
-#endif
-
 #include <libgen.h>
 #include "mod_chxj.h"
 #include "chxj_img_conv_format.h"
@@ -31,13 +21,12 @@
 #include "chxj_str_util.h"
 #include "chxj_qr_code.h"
 #include "chxj_apply_convrule.h"
+#include "chxj_url_encode.h"
 #include "qs_parse_string.h"
 
 #include "http_core.h"
 
-#if 1
 #include <wand/magick_wand.h>
-#endif
 
 
 #define EXIT_MAGICK_ERROR() \
@@ -67,7 +56,9 @@ typedef enum _ua_use_flag_t {
 /*----------------------------------------------------------------------------*/
 /* Request parameter maintenance structure                                    */
 /*----------------------------------------------------------------------------*/
-typedef struct _query_string_param_t {
+typedef struct query_string_param_t query_string_param_t;
+
+struct query_string_param_t {
   img_conv_mode_t   mode;
   char*             user_agent;
   ua_use_flag_t     ua_flag;
@@ -77,7 +68,7 @@ typedef struct _query_string_param_t {
   long              count;     /* for EZGET */
   int               width;
   int               height;
-} query_string_param_t;
+};
 
 /*----------------------------------------------------------------------------*/
 /* Device_spec when User-Agent is disregarded                                 */
@@ -170,30 +161,37 @@ static const char* HDML_FAIL_PAGE =
 /*----------------------------------------------------------------------------*/
 /* Prototype declaration                                                      */
 /*----------------------------------------------------------------------------*/
-static char*        s_create_workfile(  request_rec*, mod_chxj_config* , 
+static char*        s_create_workfile(  request_rec*, 
+                                        mod_chxj_config* , 
                                         const char*, 
                                         query_string_param_t*);
-static apr_status_t s_create_cache_file(request_rec* r, 
-                                        const char* tmpfile, 
-                                        device_table* spec,
-                                        apr_finfo_t* st,
-                                        query_string_param_t *qsp);
-static apr_status_t s_send_cache_file(  device_table* spec,
+
+static apr_status_t s_create_cache_file(request_rec*          r, 
+                                        const char*           tmpfile, 
+                                        device_table*         spec,
+                                        apr_finfo_t*          st,
+                                        query_string_param_t* qsp);
+
+static apr_status_t s_send_cache_file(  device_table*         spec,
                                         query_string_param_t* query_string,
-                                        request_rec* r,
-                                        const char* tmpfile);
-static apr_status_t s_header_only_cache_file(
-  device_table* spec, 
-  query_string_param_t* query_string, 
-  request_rec* r, 
-  const char* tmpfile);
+                                        request_rec*          r,
+                                        const char*           tmpfile);
+
+static apr_status_t s_header_only_cache_file(device_table*         spec, 
+                                             query_string_param_t* query_string, 
+                                             request_rec*          r, 
+                                             const char*           tmpfile);
+
 static query_string_param_t* s_get_query_string_param(request_rec *r);
+
 static unsigned short s_add_crc(        const char* writedata, 
                                         apr_size_t witebyte);
+
 static MagickWand* s_fixup_size(MagickWand* , 
-                                        request_rec* r, 
-                                        device_table* spec, 
-                                        query_string_param_t *qsp);
+                                request_rec* r, 
+                                device_table* spec, 
+                                query_string_param_t *qsp);
+
 static MagickWand* s_fixup_color(MagickWand* magick_wand, 
                                  request_rec* r, 
                                  device_table* spec, 
@@ -202,22 +200,24 @@ static MagickWand* s_fixup_depth(MagickWand* magick_wand,
                                  request_rec* r, device_table* spec);
 static MagickWand* s_img_down_sizing(MagickWand* magick_wand, 
                                 request_rec* r, device_table* spec);
-static MagickWand* s_add_copyright(
-                          MagickWand* magick_wand,
-                          request_rec* r,
-                          device_table* spec);
-static char* s_create_blob_data(request_rec* r,
-                   device_table* spec,
-                   query_string_param_t *qsp,
-                   char* indata,
-                   apr_size_t* len);
 
-static int s_img_conv_format_from_file(
-                request_rec*          r, 
-                mod_chxj_config*    conf, 
-                const char*           user_agent,
-                query_string_param_t* qsp,
-                device_table*       spec);
+static MagickWand* s_add_copyright(MagickWand*   magick_wand,
+                                   request_rec*  r,
+                                   device_table* spec);
+
+static char* s_create_blob_data(request_rec*          r,
+                                device_table*         spec,
+                                query_string_param_t* qsp,
+                                char*                 indata,
+                                apr_size_t*           len);
+
+static int s_img_conv_format_from_file(request_rec*          r, 
+                                       mod_chxj_config*      conf, 
+                                       const char*           user_agent,
+                                       query_string_param_t* qsp,
+                                       device_table*         spec);
+
+
 
 int 
 chxj_img_conv_format_handler(request_rec* r)
@@ -225,8 +225,8 @@ chxj_img_conv_format_handler(request_rec* r)
   mod_chxj_config*      conf;
   query_string_param_t* qsp;
   char*                 user_agent;
-  device_table*       spec;
-  chxjconvrule_entry* entryp;
+  device_table*         spec;
+  chxjconvrule_entry*   entryp;
 
   DBG(r, "start chxj_img_conv_format_handler()");
   
@@ -244,8 +244,9 @@ chxj_img_conv_format_handler(request_rec* r)
     return DECLINED;
   }
 
-  if (strcasecmp(r->handler, "chxj-qrcode") == 0 &&  conf->image == CHXJ_IMG_OFF) 
+  if (strcasecmp(r->handler, "chxj-qrcode") == 0 &&  conf->image == CHXJ_IMG_OFF) {
     return DECLINED;
+  }
 
 
   /*------------------------------------------------------------------------*/
@@ -260,10 +261,10 @@ chxj_img_conv_format_handler(request_rec* r)
   else {
     entryp = chxj_apply_convrule(r, conf->convrules);
     if (entryp && entryp->user_agent) {
-      user_agent = (char*)apr_table_get(r->headers_in, "CHXJ_HTTP_USER_AGENT");
+      user_agent = (char*)apr_table_get(r->headers_in, CHXJ_HTTP_USER_AGENT);
     }
     else {
-      user_agent = (char*)apr_table_get(r->headers_in, "User-Agent");
+      user_agent = (char*)apr_table_get(r->headers_in, HTTP_USER_AGENT);
     }
   }
 
@@ -277,8 +278,10 @@ chxj_img_conv_format_handler(request_rec* r)
   DBG1(r,"found device_name=[%s]", spec->device_name);
   DBG1(r,"User-Agent=[%s]", user_agent);
 
+#if 0
   if (spec->width == 0 || spec->heigh == 0)
     return DECLINED;
+#endif
 
   return s_img_conv_format_from_file(r, conf, user_agent, qsp, spec);
 }
@@ -328,10 +331,10 @@ chxj_exchange_image(request_rec *r, const char** src, apr_size_t* len)
   else {
     entryp = chxj_apply_convrule(r, conf->convrules);
     if (entryp && entryp->user_agent) {
-      user_agent = (char*)apr_table_get(r->headers_in, "CHXJ_HTTP_USER_AGENT");
+      user_agent = (char*)apr_table_get(r->headers_in, CHXJ_HTTP_USER_AGENT);
     }
     else {
-      user_agent = (char*)apr_table_get(r->headers_in, "User-Agent");
+      user_agent = (char*)apr_table_get(r->headers_in, HTTP_USER_AGENT);
     }
   }
 
@@ -496,138 +499,169 @@ s_create_cache_file(request_rec*       r,
     return HTTP_NOT_FOUND;
   }
 
-  /*
-   * The size of the image is changed.
-   */
-  DBG(r,"call s_fixup_size()");
-
-  if ((magick_wand = s_fixup_size(magick_wand, r, spec, qsp)) == NULL) 
-    return HTTP_NOT_FOUND;
-
-  /*
-   * The colors of the image is changed.
-   */
-  DBG(r,"call s_fixup_color()");
-
-  if ((magick_wand = s_fixup_color(magick_wand, r,spec, mode)) == NULL) 
-    return HTTP_NOT_FOUND;
-
-  /*
-   * DEPTH of the image is changed.
-   */
-  DBG(r,"call s_fixup_depth()");
-
-  if ((magick_wand = s_fixup_depth(magick_wand, r, spec)) == NULL) 
-    return HTTP_NOT_FOUND;
-
-
-
-  DBG(r,"start convert and compression");
-
-  if (spec->available_jpeg) {
-    if (MagickSetImageCompression(magick_wand,JPEGCompression) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
+  if (spec->html_spec_type != CHXJ_SPEC_UNKNOWN) {
+    /*
+     * The size of the image is changed.
+     */
+    DBG(r,"call s_fixup_size()");
+  
+    if ((magick_wand = s_fixup_size(magick_wand, r, spec, qsp)) == NULL) 
       return HTTP_NOT_FOUND;
+  
+    /*
+     * The colors of the image is changed.
+     */
+    DBG(r,"call s_fixup_color()");
+  
+    if ((magick_wand = s_fixup_color(magick_wand, r,spec, mode)) == NULL) 
+      return HTTP_NOT_FOUND;
+  
+    /*
+     * DEPTH of the image is changed.
+     */
+    DBG(r,"call s_fixup_depth()");
+  
+    if ((magick_wand = s_fixup_depth(magick_wand, r, spec)) == NULL) 
+      return HTTP_NOT_FOUND;
+  
+  
+  
+    DBG(r,"start convert and compression");
+  
+    if (spec->available_jpeg) {
+      if (MagickSetImageCompression(magick_wand,JPEGCompression) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickSetImageFormat(magick_wand, "jpg") == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickStripImage(magick_wand) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL)
+        return HTTP_NOT_FOUND;
+  
+      r->content_type = apr_psprintf(r->pool, "image/jpeg");
+      DBG(r,"convert to jpg");
     }
-
-    if (MagickSetImageFormat(magick_wand, "jpg") == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
+    else
+    if (spec->available_png) {
+  
+      if (MagickSetImageCompression(magick_wand,ZipCompression) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickSetImageFormat(magick_wand, "png") == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickStripImage(magick_wand) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
+        return HTTP_NOT_FOUND;
+  
+      r->content_type = apr_psprintf(r->pool, "image/png");
+      DBG(r, "convert to png");
     }
-
-    if (MagickStripImage(magick_wand) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
+    else
+    if (spec->available_gif) {
+  
+      if (MagickSetImageCompression(magick_wand,LZWCompression) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickSetImageFormat(magick_wand, "gif") == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickStripImage(magick_wand) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
+        return HTTP_NOT_FOUND;
+  
+      r->content_type = apr_psprintf(r->pool, "image/gif");
+  
+      DBG(r,"convert to gif");
     }
-
-    if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL)
+    else
+    if (spec->available_bmp2 || spec->available_bmp4) {
+  
+      if (MagickSetImageCompression(magick_wand,NoCompression) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickSetImageFormat(magick_wand, "bmp") == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if (MagickStripImage(magick_wand) == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
+        return HTTP_NOT_FOUND;
+  
+      r->content_type = apr_psprintf(r->pool, "image/bmp");
+  
+      DBG(r, "convert to bmp(unsupported)");
+    }
+  
+    /*
+     * Add Comment (Copyright and so on.)
+     */
+    DBG(r, "call s_add_copyright()");
+  
+    if ((magick_wand = s_add_copyright(magick_wand, r, spec)) == NULL) 
       return HTTP_NOT_FOUND;
-
-    r->content_type = apr_psprintf(r->pool, "image/jpeg");
-    DBG(r,"convert to jpg");
   }
-  else
-  if (spec->available_png) {
-
-    if (MagickSetImageCompression(magick_wand,ZipCompression) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
+  else {
+    char* fmt;
+    fmt = MagickGetImageFormat(magick_wand);
+    if (fmt == NULL) {
+      if (MagickSetImageFormat(magick_wand, "jpg") == MagickFalse) {
+        EXIT_MAGICK_ERROR();
+        return HTTP_NOT_FOUND;
+      }
+  
+      r->content_type = apr_psprintf(r->pool, "image/jpeg");
     }
-
-    if (MagickSetImageFormat(magick_wand, "png") == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
+    else {
+      if (strcasecmp(fmt, "jpg") == 0) {
+        r->content_type = apr_psprintf(r->pool, "image/jpeg");
+      }
+      else
+      if (strcasecmp(fmt, "jpeg") == 0) {
+        r->content_type = apr_psprintf(r->pool, "image/jpeg");
+      }
+      else
+      if (strcasecmp(fmt, "gif") == 0) {
+        r->content_type = apr_psprintf(r->pool, "image/gif");
+      }
+      else
+      if (strcasecmp(fmt, "png") == 0) {
+        r->content_type = apr_psprintf(r->pool, "image/png");
+      }
     }
-
-    if (MagickStripImage(magick_wand) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
-      return HTTP_NOT_FOUND;
-
-    r->content_type = apr_psprintf(r->pool, "image/png");
-    DBG(r, "convert to png");
   }
-  else
-  if (spec->available_gif) {
-
-    if (MagickSetImageCompression(magick_wand,LZWCompression) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if (MagickSetImageFormat(magick_wand, "gif") == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if (MagickStripImage(magick_wand) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
-      return HTTP_NOT_FOUND;
-
-    r->content_type = apr_psprintf(r->pool, "image/gif");
-
-    DBG(r,"convert to gif");
-  }
-  else
-  if (spec->available_bmp2 || spec->available_bmp4) {
-
-    if (MagickSetImageCompression(magick_wand,NoCompression) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if (MagickSetImageFormat(magick_wand, "bmp") == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if (MagickStripImage(magick_wand) == MagickFalse) {
-      EXIT_MAGICK_ERROR();
-      return HTTP_NOT_FOUND;
-    }
-
-    if ((magick_wand = s_img_down_sizing(magick_wand, r, spec)) == NULL) 
-      return HTTP_NOT_FOUND;
-
-    r->content_type = apr_psprintf(r->pool, "image/bmp");
-
-    DBG(r, "convert to bmp(unsupported)");
-  }
-
-  /*
-   * Add Comment (Copyright and so on.)
-   */
-  DBG(r, "call s_add_copyright()");
-
-  if ((magick_wand = s_add_copyright(magick_wand, r, spec)) == NULL) 
-    return HTTP_NOT_FOUND;
 
   writedata = (char*)MagickGetImageBlob(magick_wand, &writebyte);
 
