@@ -26,9 +26,25 @@
 #include "chxj_str_util.h"
 
 
-static void s_set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) ;
-static void s_set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) ;
-static void s_set_device_data(Doc* doc, apr_pool_t* p, device_table_list* dtl, Node* node) ;
+static void s_set_devices_data(
+  Doc*             doc, 
+  apr_pool_t*      p, 
+  mod_chxj_config* conf, 
+  Node*            node) ;
+
+static void s_set_user_agent_data(
+  Doc*             doc, 
+  apr_pool_t*      p, 
+  mod_chxj_config* conf, 
+  Node*            node);
+
+static void s_set_device_data(
+  Doc*        doc, 
+  apr_pool_t* p, 
+  device_table_list* dtl, 
+  Node* node) ;
+
+
 /**
  * load device_data.xml
  */
@@ -37,9 +53,9 @@ chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config* conf)
 {
   conf->devices = NULL;
   s_set_devices_data(doc, p, conf,qs_get_root(doc));
-
 }
 
+
 /**
  * <devices>
  */
@@ -52,7 +68,9 @@ s_set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
        child ; 
        child = qs_get_next_node(doc,child)) {
 
-    char* name = qs_get_node_name(doc,child);
+    char* name;
+
+    name = qs_get_node_name(doc,child);
 
     if ((*name == 'd' || *name == 'D') && strcasecmp(name, "devices") == 0)
       s_set_user_agent_data(doc, p, conf, child);
@@ -65,13 +83,16 @@ s_set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
 static void
 s_set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) 
 {
-  Node* child;
+  Node*              child;
   device_table_list* t;
 
   for (child = qs_get_child_node(doc,node);
        child ;
        child = qs_get_next_node(doc,child)) {
-    char* name = qs_get_node_name(doc,child);
+
+    char* name;
+
+    name = qs_get_node_name(doc,child);
 
     if ((*name == 'u' || *name == 'U') && strcasecmp(name, "user_agent") == 0 ) {
       Attr* attr;
