@@ -59,6 +59,7 @@ tag_handlers chxj_tag_handlers[] = {
   },
 };
 
+
 /**
  * It is main processing of conversion from CHTML to XXML. 
  *
@@ -94,7 +95,9 @@ chxj_node_exchange(
        child;
        child = qs_get_next_node(doc,child)) {
 
-    char* name = qs_get_node_name(doc,child);
+    char* name;
+
+    name = qs_get_node_name(doc,child);
 
     switch(*name) {
     case 'h':
@@ -279,9 +282,9 @@ chxj_node_exchange(
 
     case 'l':
     case 'L':
-      /*------------------------------------------------------------------------*/
-      /* <LI>                                                                   */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <LI>                                                                 */
+      /*----------------------------------------------------------------------*/
       if (strcasecmp(name, "li") == 0) {
         if (handlers[tagLI].start_tag_handler) 
           handlers[tagLI].start_tag_handler(pdoc, child);
@@ -291,6 +294,33 @@ chxj_node_exchange(
         if (handlers[tagLI].end_tag_handler)
           handlers[tagLI].end_tag_handler(pdoc, child);
       }
+      else
+      /*----------------------------------------------------------------------*/
+      /* <LEGEND>                                                             */
+      /*----------------------------------------------------------------------*/
+      if (strcasecmp(name, "legend") == 0) {
+        if (handlers[tagLEGEND].start_tag_handler) 
+          handlers[tagLEGEND].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagLEGEND].end_tag_handler)
+          handlers[tagLEGEND].end_tag_handler(pdoc, child);
+      }
+      else
+      /*----------------------------------------------------------------------*/
+      /* <LABEL>                                                              */
+      /*----------------------------------------------------------------------*/
+      if (strcasecmp(name, "label") == 0) {
+        if (handlers[tagLABEL].start_tag_handler) 
+          handlers[tagLABEL].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagLABEL].end_tag_handler)
+          handlers[tagLABEL].end_tag_handler(pdoc, child);
+      }
+      
       break;
 
     case 'o':
@@ -341,6 +371,19 @@ chxj_node_exchange(
 
     case 'b':
     case 'B':
+      /*----------------------------------------------------------------------*/
+      /* <B>                                                                  */
+      /*----------------------------------------------------------------------*/
+      if (strlen(name) == 1) {
+        if (handlers[tagB].start_tag_handler) 
+          handlers[tagB].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagB].end_tag_handler)
+          handlers[tagB].end_tag_handler(pdoc, child);
+      }
+      else
       /*----------------------------------------------------------------------*/
       /* <BASE>                                                               */
       /*----------------------------------------------------------------------*/
@@ -424,6 +467,19 @@ chxj_node_exchange(
         if (handlers[tagFORM].end_tag_handler)
           handlers[tagFORM].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <FIELDSET>                                                           */
+      /*----------------------------------------------------------------------*/
+      else
+      if (strcasecmp(name, "fieldset") == 0) {
+        if (handlers[tagFIELDSET].start_tag_handler) 
+          handlers[tagFIELDSET].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagFIELDSET].end_tag_handler)
+          handlers[tagFIELDSET].end_tag_handler(pdoc, child);
+      }
       break;
 
     case 'i':
@@ -476,8 +532,9 @@ chxj_node_exchange(
       if (strcasecmp(name, "style") == 0) {
         if (handlers[tagSTYLE].start_tag_handler) 
           handlers[tagSTYLE].start_tag_handler(pdoc, child);
-
+#if 0
         chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+#endif
 
         if (handlers[tagSTYLE].end_tag_handler)
           handlers[tagSTYLE].end_tag_handler(pdoc, child);
@@ -528,9 +585,9 @@ chxj_node_exchange(
 
     case 'c':
     case 'C':
-      /*------------------------------------------------------------------------*/
-      /* <CENTER>                                                               */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <CENTER>                                                             */
+      /*----------------------------------------------------------------------*/
       if (strcasecmp(name, "center") == 0) {
         if (handlers[tagCENTER].start_tag_handler) 
           handlers[tagCENTER].start_tag_handler(pdoc, child);
@@ -540,9 +597,9 @@ chxj_node_exchange(
         if (handlers[tagCENTER].end_tag_handler)
           handlers[tagCENTER].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <CHXJ:IF>                                                              */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <CHXJ:IF>                                                            */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "chxj:if") == 0) {
         if (chxj_chxjif_is_mine(spec, doc, child)) {
@@ -588,9 +645,9 @@ chxj_node_exchange(
         if (handlers[tagTITLE].end_tag_handler)
           handlers[tagTITLE].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <TABLE>                                                                */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <TABLE>                                                              */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "table") == 0) {
         if (handlers[tagTABLE].start_tag_handler) 
@@ -601,9 +658,9 @@ chxj_node_exchange(
         if (handlers[tagTABLE].end_tag_handler)
           handlers[tagTABLE].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <TBODY>                                                                */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <TBODY>                                                              */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "tbody") == 0) {
         if (handlers[tagTBODY].start_tag_handler) 
@@ -614,9 +671,9 @@ chxj_node_exchange(
         if (handlers[tagTBODY].end_tag_handler)
           handlers[tagTBODY].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <TH>                                                                   */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <TH>                                                                 */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "th") == 0) {
         if (handlers[tagTH].start_tag_handler) 
@@ -627,9 +684,9 @@ chxj_node_exchange(
         if (handlers[tagTH].end_tag_handler)
           handlers[tagTH].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <TR>                                                                   */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <TR>                                                                 */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "tr") == 0) {
         if (handlers[tagTR].start_tag_handler) 
@@ -640,9 +697,9 @@ chxj_node_exchange(
         if (handlers[tagTR].end_tag_handler)
           handlers[tagTR].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* <TD>                                                                   */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* <TD>                                                                 */
+      /*----------------------------------------------------------------------*/
       else
       if (strcasecmp(name, "td") == 0) {
         if (handlers[tagTD].start_tag_handler) 
@@ -653,11 +710,11 @@ chxj_node_exchange(
         if (handlers[tagTD].end_tag_handler)
           handlers[tagTD].end_tag_handler(pdoc, child);
       }
-      /*------------------------------------------------------------------------*/
-      /* NORMAL TEXT                                                            */
-      /*------------------------------------------------------------------------*/
+      /*----------------------------------------------------------------------*/
+      /* NORMAL TEXT                                                          */
+      /*----------------------------------------------------------------------*/
       else
-      if ((*name == 't' || *name == 'T') && strcasecmp(name, "text") == 0) {
+      if (strcasecmp(name, "text") == 0) {
         if (handlers[tagTEXT].start_tag_handler)
           handlers[tagTEXT].start_tag_handler(pdoc, child);
       }
@@ -668,6 +725,8 @@ chxj_node_exchange(
     }
   }
 
-
   return NULL;
 }
+/*
+ * vim:ts=2 et
+ */
