@@ -14,15 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#if 0
-#include <wand/magick_wand.h>
-
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#endif
 #include <unistd.h>
 #include <assert.h>
 #include "apr_strings.h"
@@ -599,9 +590,8 @@ chxj_qr_code_handler(request_rec* r)
   Node*              root;
   mod_chxj_config*   conf;
 
-#ifdef QR_CODE_DEBUG
   DBG(r,"start chxj_qr_code_handler()");
-#endif
+
   if (strcasecmp(r->handler, "chxj-qrcode")) {
     DBG(r, "end chxj_qr_code_handler()");
     return DECLINED;
@@ -643,6 +633,7 @@ chxj_qr_code_handler(request_rec* r)
   return OK;
 }
 
+
 char* 
 chxj_qr_code_blob_handler(request_rec* r, const char* indata, size_t* len)
 {
@@ -684,11 +675,12 @@ chxj_qr_code_blob_handler(request_rec* r, const char* indata, size_t* len)
   return img;
 }
 
+
 int
 chxj_qrcode_create_image_data(
   qr_code_t* qrcode,
-  char** img,
-  size_t* img_len)
+  char**     img,
+  size_t*    img_len)
 {
   int                xx, yy;
   int                module_count;
@@ -764,7 +756,11 @@ chxj_qrcode_create_image_data(
     status = MagickResizeImage(magick_wand, ((module_count)*4+6), ((module_count)*4+6) , LanczosFilter,0.0);
   }
   else {  
-    status = MagickResizeImage(magick_wand, (module_count * qrcode->size + 6), (module_count * qrcode->size + 6) , LanczosFilter,0.0);
+    status = MagickResizeImage(magick_wand, 
+                               (module_count * qrcode->size + 6), 
+                               (module_count * qrcode->size + 6) , 
+                               LanczosFilter,
+                               0.0);
   }
   if (status == MagickFalse) 
     goto on_error;
@@ -850,15 +846,19 @@ chxj_qr_code(qr_code_t* qrcode, char* module[])
     case QR_NUM_MODE:
       real_data = s_data_to_bin_num(qrcode, data_code_count);
       break;
+
     case QR_ALPHA_MODE:
       real_data = s_data_to_bin_alpha(qrcode, data_code_count);
       break;
+
     case QR_8BIT_MODE:
       real_data = s_data_to_bin_8bit(qrcode,data_code_count);
       break;
+
     case QR_KANJI_MODE:
       real_data = s_data_to_bin_kanji(qrcode,data_code_count);
       break;
+
     default:
       qrcode->mode = QR_8BIT_MODE;
       qrcode->mode_change = QR_CHANGE;
@@ -932,23 +932,20 @@ chxj_qr_code(qr_code_t* qrcode, char* module[])
   /*--------------------------------------------------------------------------*/
   min_lost_point = -1;
   min_mask_pattern = -1;
-  for (ii=0; ii<8; ii++)
-  {
+  for (ii=0; ii<8; ii++) {
     int lost_point;
     s_init_modules(qrcode, ii, module);
     s_map_data(qrcode,  module, (unsigned char*)eccstr, data_total_count, ii);
     lost_point = s_calc_lost_point(qrcode, module);
-    if (min_mask_pattern == -1)
-    {
+
+    if (min_mask_pattern == -1) {
       min_mask_pattern = ii;
-      min_lost_point = lost_point;
+      min_lost_point   = lost_point;
     }
-    else
-    {
-      if (min_lost_point >= lost_point)
-      {
+    else {
+      if (min_lost_point >= lost_point) {
         min_mask_pattern = ii;
-        min_lost_point = lost_point;
+        min_lost_point   = lost_point;
       }
     }
   }
@@ -959,6 +956,7 @@ chxj_qr_code(qr_code_t* qrcode, char* module[])
 #ifdef QR_CODE_DEBUG
   DBG1(r, "selected mask[%d]", min_mask_pattern);
 #endif
+
   s_init_modules(qrcode, min_mask_pattern, module);
   s_map_data(qrcode, 
              module, 
@@ -975,16 +973,14 @@ chxj_qr_code(qr_code_t* qrcode, char* module[])
     int xx, yy;
     int module_count = v_module_count_table[qrcode->version];
     DBG1(r,"loop to [%d]", module_count);
-    for (yy=0; yy<module_count; yy++)
-    {
+    for (yy=0; yy<module_count; yy++) {
       char *rows ;
 
       rows = apr_psprintf(r->pool, " ");
       
       for (xx=0; xx<module_count; xx++)
-      {
         rows = apr_pstrcat(r->pool, rows, "[", apr_psprintf(r->pool, "%c", module[yy][xx]), "]", NULL);
-      }
+
       DBG2(r,"%d:%s", yy,rows);
     }
   } while(0);
@@ -999,17 +995,23 @@ chxj_qr_code(qr_code_t* qrcode, char* module[])
 void
 chxj_qrcode_node_to_qrcode(qr_code_t* qrcode, Node* node)
 {
-  request_rec* r = qrcode->r;
-  Doc* doc = qrcode->doc;
-  Node* child;
+  request_rec* r;
+  Doc*         doc;
+  Node*        child;
+
+  r   = qrcode->r;
+  doc = qrcode->doc;
 
   for (child = qs_get_child_node(doc,node);
        child ;
-       child = qs_get_next_node(doc,child))
-  {
-    char* name = qs_get_node_name(doc,child);
-    if (strcasecmp("qrcode",name) == 0)
-    {
+       child = qs_get_next_node(doc,child)) {
+
+    char* name;
+
+    name = qs_get_node_name(doc,child);
+
+    if (strcasecmp("qrcode",name) == 0) {
+
       qrcode->found       = QR_FOUND;
       qrcode->mode_change = QR_NOT_CHANGE;
       qrcode->version     = QR_VER_5;
@@ -1020,38 +1022,35 @@ chxj_qrcode_node_to_qrcode(qr_code_t* qrcode, Node* node)
       chxj_qrcode_node_to_qrcode(qrcode, child);
     }
     else
-    if (strcasecmp("version", name) == 0)
-    {
-      int ver;
-      Node* cchild = qs_get_child_node(doc, child);
+    if (strcasecmp("version", name) == 0) {
+      int   ver;
+      Node* cchild;
       char* value;
-      if (cchild == NULL)
-      {
+
+      cchild = qs_get_child_node(doc, child);
+
+      if (cchild == NULL) {
         qrcode->version = QR_VER_1;
         continue;
       }
 
       name = qs_get_node_name(doc, cchild);
       value = qs_get_node_value(doc, cchild);
-      if (strcasecmp("TEXT", name) != 0)
-      {
+      if (strcasecmp("TEXT", name) != 0) {
         qrcode->version = QR_VER_1;
         continue;
       }
-      if (value == NULL || strlen(value) == 0)
-      {
+      if (value == NULL || strlen(value) == 0) {
         qrcode->version = QR_VER_1;
         continue;
       }
 
-      if (chxj_chk_numeric(value))
-      {
+      if (chxj_chk_numeric(value)) {
         qrcode->version = QR_VER_1;
         continue;
       }
       ver = chxj_atoi(value);
-      if (ver <= 0 || ver > 40)
-      {
+      if (ver <= 0 || ver > 40) {
         qrcode->version = QR_VER_1;
         continue;
       }
@@ -1059,46 +1058,38 @@ chxj_qrcode_node_to_qrcode(qr_code_t* qrcode, Node* node)
       qrcode->version = ver - 1;
     }
     else
-    if (strcasecmp("level", name) == 0)
-    {
+    if (strcasecmp("level", name) == 0) {
       Node* cchild = qs_get_child_node(doc, child);
       char* value;
-      if (cchild == NULL)
-      {
+      if (cchild == NULL) {
         qrcode->level = QR_LEVEL_L;
         continue;
       }
-      name = qs_get_node_name(doc, cchild);
+      name  = qs_get_node_name(doc, cchild);
       value = qs_get_node_value(doc, cchild);
-      if (strcasecmp("TEXT", name) != 0)
-      {
+      if (strcasecmp("TEXT", name) != 0) {
         qrcode->level = QR_LEVEL_L;
         continue;
       }
 
-      if (value == NULL || strlen(value) == 0)
-      {
+      if (value == NULL || strlen(value) == 0) {
         qrcode->level = QR_LEVEL_L;
         continue;
       }
 
-      if (strcasecmp("L", value) == 0)
-      {
+      if (strcasecmp("L", value) == 0) {
         qrcode->level = QR_LEVEL_L;
       }
       else
-      if (strcasecmp("M", value) == 0)
-      {
+      if (strcasecmp("M", value) == 0) {
         qrcode->level = QR_LEVEL_M;
       }
       else
-      if (strcasecmp("Q", value) == 0)
-      {
+      if (strcasecmp("Q", value) == 0) {
         qrcode->level = QR_LEVEL_Q;
       }
       else
-      if (strcasecmp("H", value) == 0)
-      {
+      if (strcasecmp("H", value) == 0) {
         qrcode->level = QR_LEVEL_H;
       }
       else
@@ -2174,26 +2165,30 @@ s_calc_lost_point(qr_code_t* qrcode, char* dst[])
 static int
 s_count_same_module(qr_ver_t ver, char* dst[])
 {
-  int module_count = v_module_count_table[ver];
-  int point = 0;
+  int module_count;
+  int point;
   int xx, yy;
-  int same_count = 0;
-  int prev_value = -1;
+  int same_count;
+  int prev_value;
+
+  module_count = v_module_count_table[ver];
+  point        = 0;
+  same_count   = 0;
+  prev_value   = -1;
 
   /* ǥå */
   for (yy=0; yy<module_count; yy++) {
     prev_value = -1;
     same_count = 0;
     for (xx=0; xx<module_count; xx++) {
-      if (prev_value == (unsigned char)dst[yy][xx]) {
+      if (prev_value == (unsigned char)dst[yy][xx])
         same_count++;
-      }
-      else {
+      else
         same_count = 0;
-      }
-      if (same_count >= 5) {
+
+      if (same_count >= 5) 
         point++;
-      }
+
       prev_value = (unsigned char)dst[yy][xx];
     }
   }
@@ -2230,11 +2225,13 @@ s_count_same_module(qr_ver_t ver, char* dst[])
 static int
 s_count_same_block(qr_ver_t ver, char* dst[])
 {
-  int module_count = v_module_count_table[ver];
+  int module_count;
   int point;
   int count;
   int xx,yy;
 
+  module_count = v_module_count_table[ver];
+
   point = 0;
   for (yy = 0; yy < module_count-1; yy++) {
     for (xx = 0; xx < module_count-1; xx++) {
@@ -2254,10 +2251,12 @@ s_count_same_block(qr_ver_t ver, char* dst[])
 static int
 s_count_11311_pattern(qr_ver_t ver, char* dst[])
 {
-  int module_count = v_module_count_table[ver];
+  int module_count;
   int point;
   int xx,yy;
 
+  module_count = v_module_count_table[ver];
+
   point = 0;
   /* Υå */
   for (yy = 0; yy < module_count; yy++) {
@@ -2291,17 +2290,23 @@ s_count_11311_pattern(qr_ver_t ver, char* dst[])
 
   return point;
 }
+
+
 /* 
  * Τť⥸塼γ 50(5+k)%50(5+(k+1))% 
  */
 static int
 s_count_dark_ratio(qr_ver_t ver, char* dst[])
 {
-  int module_count = v_module_count_table[ver];
-  int dark_count = 0;
+  int module_count;
+  int dark_count;
   int xx, yy;
   int ratio;
-  int all_count = module_count * module_count;
+  int all_count;
+
+  module_count = v_module_count_table[ver];
+  dark_count   = 0;
+  all_count    = module_count * module_count;
 
   /* ñ""򥫥Ȥ */
   for (yy=0; yy<module_count; yy++) {
