@@ -39,8 +39,11 @@ qs_get_value_attr(Doc* doc, Node* node, request_rec* r)
        attr;
        attr = qs_get_next_attr(doc,attr)) {
 
-    char* name  = qs_get_attr_name(doc,attr);
-    char* value = qs_get_attr_value(doc,attr);
+    char* name;
+    char* value;
+
+    name  = qs_get_attr_name(doc,attr);
+    value = qs_get_attr_value(doc,attr);
 
     if ((*name == 'v' || *name == 'V') && strcasecmp(name, "value") == 0)
       /*----------------------------------------------------------------------*/
