@@ -84,6 +84,8 @@ static char* s_xhtml_1_0_start_div_tag    (void* pdoc, Node* node);
 static char* s_xhtml_1_0_end_div_tag      (void* pdoc, Node* node);
 static char* s_xhtml_1_0_start_textarea_tag(void* pdoc, Node* node);
 static char* s_xhtml_1_0_end_textarea_tag  (void* pdoc, Node* node);
+static char* s_xhtml_1_0_start_b_tag       (void* pdoc, Node* node);
+static char* s_xhtml_1_0_end_b_tag         (void* pdoc, Node* node);
 static char* s_xhtml_1_0_chxjif_tag       (void* pdoc, Node* node);
 
 static void  s_init_xhtml(xhtml_t* xhtml, Doc* doc, request_rec* r, device_table* spec);
@@ -292,6 +294,31 @@ tag_handler xhtml_handler[] = {
     NULL,
     NULL,
   },
+  /* tagB */
+  {
+    s_xhtml_1_0_start_b_tag,
+    s_xhtml_1_0_end_b_tag,
+  },
+  /* tagFIELDSET */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagDT */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLEGEND */
+  {
+    NULL,
+    NULL,
+  },
+  /* tagLABEL */
+  {
+    NULL,
+    NULL,
+  },
 };
  
 /**
@@ -310,7 +337,8 @@ chxj_exchange_xhtml_mobile_1_0(
   const char*     src,
   apr_size_t      srclen,
   apr_size_t*     dstlen,
-  chxjconvrule_entry* entryp
+  chxjconvrule_entry* entryp,
+  cookie_t*   cookie
 )
 {
   char*     dst = NULL;
@@ -1014,6 +1042,7 @@ s_xhtml_1_0_start_a_tag(void* pdoc, Node* node)
                       "\"", 
                       NULL);
 #else
+      value = chxj_encoding_parameter(r, value);
       xhtml->out = apr_pstrcat(r->pool, 
                       xhtml->out, 
                       " href=\"", 
@@ -1260,6 +1289,7 @@ s_xhtml_1_0_start_form_tag(void* pdoc, Node* node)
     char* name = qs_get_attr_name(doc,attr);
     char* value = qs_get_attr_value(doc,attr);
     if ((*name == 'a' || *name == 'A') && strcasecmp(name, "action") == 0) {
+      value = chxj_encoding_parameter(r, value);
       xhtml->out = apr_pstrcat(r->pool, 
                       xhtml->out, 
                       " action=\"",
@@ -2036,6 +2066,7 @@ s_xhtml_1_0_start_img_tag(void* pdoc, Node* node)
     char* value = qs_get_attr_value(doc,attr);
 
     if ((*name == 's' || *name == 'S') && strcasecmp(name, "src") == 0) {
+      value = chxj_encoding_parameter(r, value);
 #ifdef IMG_NOT_CONVERT_FILENAME
       xhtml->out = apr_pstrcat(r->pool, 
                       xhtml->out, " src=\"",value,"\"", NULL);
@@ -2313,6 +2344,48 @@ s_xhtml_1_0_end_div_tag(void* pdoc, Node* child)
 }
 
 
+/**
+ * It is a handler who processes the B tag.
+ *
+ * @param pdoc  [i/o] The pointer to the XHTML structure at the output
+ *                     destination is specified.
+ * @param node   [i]   The B tag node is specified.
+ * @return The conversion result is returned.
+ */
+static char*
+s_xhtml_1_0_start_b_tag(void* pdoc, Node* child)
+{
+  xhtml_t*     xhtml = GET_XHTML(pdoc);
+  Doc*         doc   = xhtml->doc;
+  request_rec* r     = doc->r;
+
+  xhtml->out = apr_pstrcat(r->pool, xhtml->out, "<div style=\"font-weight:bold\">", NULL);
+
+  return xhtml->out;
+}
+
+
+/**
+ * It is a handler who processes the B tag.
+ *
+ * @param pdoc  [i/o] The pointer to the XHTML structure at the output
+ *                     destination is specified.
+ * @param node   [i]   The B tag node is specified.
+ * @return The conversion result is returned.
+ */
+static char*
+s_xhtml_1_0_end_b_tag(void* pdoc, Node* child)
+{
+  xhtml_t*     xhtml = GET_XHTML(pdoc);
+  Doc*         doc   = xhtml->doc;
+  request_rec* r     = doc->r;
+
+  xhtml->out = apr_pstrcat(r->pool, xhtml->out, "</div>\n", NULL);
+
+  return xhtml->out;
+}
+
+
 /**
  * It is a handler who processes the CHXJ:IF tag.
  *
