@@ -23,7 +23,9 @@ int
 qs_ignore_sp(Doc* doc, const char* s, int len) 
 {
   int ii;
-  char* sp = (char*)s;
+  char* sp;
+
+  sp = (char*)s;
 
   for(ii=0;
       *sp && is_white_space(*sp) && ii<len;
@@ -33,16 +35,17 @@ qs_ignore_sp(Doc* doc, const char* s, int len)
   return (sp - s);
 }
 
+
 int
 qs_ignore_sp_and_quote(Doc* doc, const char* s, int len) 
 {
-  int ii;
+  int   ii;
   char* sp = (char*)s;
 
   for(ii=0;
       *sp && (is_white_space(*sp) || is_quote(*sp)) && ii<len;
-      ii++, sp++) 
-          ;
+      ii++, sp++)
+        ;
 
   return (sp - s);
 }
