@@ -43,17 +43,21 @@ static void qs_dump_node(Doc* doc, Node* node, int indent);
 Node*
 qs_parse_string(Doc* doc, const char* src, int srclen) 
 {
-  int ii;
-  char encoding[256];
-  char* osrc = NULL;
-  char* ibuf = NULL;
-  int olen;
-  int ilen;
+  int     ii;
+  char    encoding[256];
+  char*   osrc;
+  char*   ibuf;
+  int     olen;
+  int     ilen;
   iconv_t cd;
 
+  osrc = NULL;
+  ibuf = NULL;
+
   memset(encoding, 0, 256);
 
   doc->now_parent_node = qs_init_root_node(doc);
+
   /* 
    * It is the pre reading. 
    * Because I want to specify encoding.
@@ -78,12 +82,18 @@ qs_parse_string(Doc* doc, const char* src, int srclen)
           if ((*parse_attr->name == 'e' || *parse_attr->name == 'E')
           &&   strcasecmp(parse_attr->name, "encoding") == 0) {
             switch (*parse_attr->value) {
+            case 'X':
+            case 'x':
+              if (strcasecmp(parse_attr->value, "x-sjis"   ) == 0) {
+                strcpy((char*)encoding, (char*)"NONE");
+              }
+              break;
+
             case 'S':
             case 's':
               if ((strcasecmp(parse_attr->value, "Shift_JIS") == 0)
-              ||  (strcasecmp(parse_attr->value, "sjis"     ) == 0)
-              ||  (strcasecmp(parse_attr->value, "Shift-JIS") == 0)
-              ||  (strcasecmp(parse_attr->value, "x-sjis"   ) == 0)) {
+              ||  (strcasecmp(parse_attr->value, "SJIS"     ) == 0)
+              ||  (strcasecmp(parse_attr->value, "Shift-JIS") == 0)) {
                 strcpy((char*)encoding, (char*)"NONE");
               }
               break;
@@ -154,14 +164,25 @@ qs_parse_string(Doc* doc, const char* src, int srclen)
 
       ii += endpoint;
       if (node->name[0] == '/' ) {
-
-        if ((doc->parse_mode == PARSE_MODE_CHTML && has_child(&(node->name[1])))
-        ||  (doc->parse_mode == PARSE_MODE_NO_PARSE 
-        &&  (node->name[1] == 'c' || node->name[1] == 'C')
-        &&  strcasecmp(&node->name[1], "chxj:if") == 0)) {
-          if (doc->now_parent_node->parent != NULL) {
-            doc->now_parent_node = doc->now_parent_node->parent;
-            doc->parse_mode = PARSE_MODE_CHTML;
+        if (doc->parse_mode == PARSE_MODE_CHTML) {
+          if (has_child(&(node->name[1]))) {
+            if (doc->now_parent_node->parent != NULL) {
+              doc->now_parent_node = doc->now_parent_node->parent;
+              doc->parse_mode = PARSE_MODE_CHTML;
+            }
+          }
+          else {
+            continue;
+          }
+        }
+        else
+        if (doc->parse_mode == PARSE_MODE_NO_PARSE) {
+          if ((node->name[1] == 'c' || node->name[1] == 'C')
+          &&  strcasecmp(&node->name[1], "chxj:if") == 0) {
+            if (doc->now_parent_node->parent != NULL) {
+              doc->now_parent_node = doc->now_parent_node->parent;
+              doc->parse_mode = PARSE_MODE_CHTML;
+            }
           }
         }
 
@@ -178,9 +199,7 @@ qs_parse_string(Doc* doc, const char* src, int srclen)
         if (node->name[0] == '/')
           continue;
       }
-#ifdef DEBUG
-  QX_LOGGER_DEBUG("return from qs_add_child_node()");
-#endif
+
       if (doc->parse_mode == PARSE_MODE_CHTML && 
       (*node->name == 'c' || *node->name == 'C') &&
       strcasecmp(node->name, "chxj:if") == 0) {
@@ -236,6 +255,7 @@ qs_parse_string(Doc* doc, const char* src, int srclen)
   return doc->root_node;
 }
 
+
 static void
 qs_dump_node(Doc* doc, Node* node, int indent) 
 {
@@ -321,7 +341,7 @@ s_cut_text(const char* s, int len)
 Node*
 qs_init_root_node(Doc* doc) 
 {
-  doc->root_node = (Node*)apr_palloc(doc->pool,sizeof(struct _node));
+  doc->root_node = (Node*)apr_palloc(doc->pool,sizeof(struct Node));
   if (doc->root_node == NULL) 
     QX_LOGGER_FATAL("Out Of Memory");
 
